sagace.exceptions.infrastructure package — sagace 2025 documentation

# sagace.exceptions.infrastructure package

## Submodules

## sagace.exceptions.infrastructure.authentication_error module

### Module: Authentication Errors

Este módulo define a exceção AuthenticationFailedError, utilizada para indicar falhas no processo de autenticação.

Obs.:

- Segue os princípios da Clean Architecture, separando a lógica de erro do domínio da aplicação.

- Aplica o princípio Liskov Substitution Principle (LSP), pois AuthenticationFailedError estende InfrastructureError sem modificar o comportamento esperado da classe base.

Author: @diego.yosiura Last Update: 27/02/2025 16:07 Created: 27/02/2025 16:07 Copyright: (c) Ampere Consultoria Ltda Original Project: sagace-v2-package IDE: PyCharm

exception sagace.exceptions.infrastructure.authentication_error.AuthenticationFailedError

  Bases: `InfrastructureError`

  Exceção que representa uma falha no processo de autenticação de um usuário.

  Esta exceção deve ser lançada quando a autenticação falha devido a credenciais inválidas ou outros problemas que impeçam a autenticação bem-sucedida.

  Herda de:

    InfrastructureError: Classe base para erros de infraestrutura.

  Exemplo de uso:

        >>> raise AuthenticationFailedError()

## sagace.exceptions.infrastructure.infrastructure_error module

### Module: Infrastructure Errors

Este módulo define a exceção base InfrastructureError, utilizada para representar erros relacionados à infraestrutura.

Obs.:

- Segue os princípios da Clean Architecture, separando os erros de infraestrutura do domínio da aplicação.

- Aplica o princípio Liskov Substitution Principle (LSP), pois outras exceções específicas podem herdar de InfrastructureError sem modificar seu comportamento esperado.

Author: @diego.yosiura Last Update: 27/02/2025 16:05 Created: 27/02/2025 16:05 Copyright: (c) Ampere Consultoria Ltda Original Project: sagace-v2-package IDE: PyCharm

exception sagace.exceptions.infrastructure.infrastructure_error.InfrastructureError

  Bases: `Exception`

  Exceção base para representar erros de infraestrutura.

  Esta classe deve ser utilizada como base para todas as exceções relacionadas à infraestrutura, como falhas de conexão, indisponibilidade de serviços e erros de comunicação com APIs externas.

  Herda de:

    Exception: Classe base de todas as exceções nativas do Python.

  Exemplo de uso:

        >>> raise InfrastructureError("Falha ao conectar ao banco de dados")

## Module contents

### Description:

Obs.:

Author: @diego.yosiura Last Update: 27/02/2025 16:03 Created: 27/02/2025 16:03 Copyright: (c) Ampere Consultoria Ltda Original Project: sagace-v2-package IDE: PyCharm